[hide private]
[frames] | no frames]

[ Identifiers | To Do ]

# To Do List

To Do in translate.storage.qm We can only parse, not create, a .qm file. The main issue is that we need to implement the hashing algorithm (which seems to be identical to the Gettext hash algorithm). Unlike Gettext it seems that the hash is required, but that has not been validated. The code can parse files correctly. But it could be cleaned up to be more readable, especially the part that breaks the file into sections.